@@ -1,6 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper::Reports::Id;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Reports::Web::Controller::Tapper::Reports::Id::VERSION = '5.0.0';
+$Tapper::Reports::Web::Controller::Tapper::Reports::Id::VERSION = '5.0.1';
 use 5.010;
 use strict;
 use warnings;
@@ -75,7 +75,7 @@ sub get_report_failures
 {
         my ($self, $report) = @_;
 
-        return $report->get_cached_tapdom ~~ dpath '//tap//lines//is_ok[value eq 0]/..';
+        return [ dpath('//tap//lines//is_ok[value eq 0]/..')->match($report->get_cached_tapdom) ];
 }
 
 sub index :Path :Args(1)
