@@ -1,6 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper::Testruns;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Reports::Web::Controller::Tapper::Testruns::VERSION = '5.0.0';
+$Tapper::Reports::Web::Controller::Tapper::Testruns::VERSION = '5.0.1';
 use parent 'Tapper::Reports::Web::Controller::Base';
 use Cwd;
 use Data::DPath 'dpath';
@@ -70,7 +70,7 @@ sub get_testrun_overview : Private
                         $retval->{name}  = $precondition->{name} || "Virtualisation Test";
                         $retval->{arch}  = $precondition->{host}->{root}{arch};
                         $retval->{image} = $precondition->{host}->{root}{image} || $precondition->{host}->{root}{name}; # can be an image or copyfile or package
-                        ($retval->{xen_package}) = grep { m!repository/packages/xen/builds! } @{ $precondition ~~ dpath '/host/preconditions//filename' };
+                        ($retval->{xen_package}) = grep { m!repository/packages/xen/builds! } dpath('/host/preconditions//filename')->match($precondition);
                         push @{$retval->{test}}, get_test_list_from_precondition($precondition->{host});
 
                         foreach my $guest (@{$precondition->{guests}}) {
@@ -443,7 +443,7 @@ sub handle_precondition
                 next if $name eq 'submit';
                 # checkboxgroups return an array but since you don't
                 # know its order in advance its easier to access a hash
-                if (ref $all_form_elements{$name} ~~ 'ARRAY') {
+                if (ref $all_form_elements{$name} =~ /ARRAY/) {
                         foreach my $element (@{$all_form_elements{$name}}) {
                                 $macros{$name}->{$element} = 1;
                         }
